# DailyTasks #
A tasks manager for those who like work from shell.

## Installation ##
**Requirements:**
- Python >= 3.11

**How install it:**

`pip install dailytasks`

## Contributing ##
Read [Contributing file](https://github.com/LuisanaMT2005/DailyTasks/blob/main/CONTRIBUTING.md) and make whatever question in Discussions.

### Thanks to ###
[Krishnag09](https://github.com/Krishnag09) for contributing closing [#2](https://github.com/LuisanaMTDev/dailytasks/issues/2) and [#8](https://github.com/LuisanaMTDev/dailytasks/issues/8) issues.
